@@ -72,6 +72,13 @@ public:
      */
     int del_user(int id)
     {
+        if (admins.contains(id))
+        {
+            string error;
+
+            del_admin(id, error);
+        }
+
         return users.del(id);
     }
 
@@ -203,7 +210,7 @@ private:
     {
         ostringstream oss_group(Group::db_bootstrap);
 
-        return db->exec(oss_group);
+        return db->exec_local_wr(oss_group);
     };
 
     /**
