@@ -34,7 +34,7 @@ public:
     /* ---------------------------------------------------------------------- */
     IPAMRequest(const std::string& _ar_xml) :
         ar_xml(_ar_xml), address_xml("<ADDRESS><MAC/><IP/><IP6_GLOBAL/>"
-                "<IP6_ULA/><SIZE/></ADDRESS>"){};
+                "<IP6_ULA/><IP6/><SIZE/></ADDRESS>"){};
 
     IPAMRequest(const std::string& _ar_xml, const std::string& _address_xml) :
         ar_xml(_ar_xml), address_xml(_address_xml){};
@@ -57,6 +57,7 @@ public:
      *      <ADDRESS>
      *        <MAC>
      *        <IP>
+     *        <IP6>
      *        <IP6_ULA>
      *        <IP6_GLOBAL>
      *        <SIZE>
