@@ -1031,6 +1031,7 @@ TM_VCENTER_FILES="src/tm_mad/vcenter/clone \
                  src/tm_mad/vcenter/cpds \
                  src/tm_mad/vcenter/premigrate \
                  src/tm_mad/vcenter/postmigrate \
+                 src/tm_mad/vcenter/resize \
                  src/tm_mad/vcenter/snap_create \
                  src/tm_mad/vcenter/snap_create_live \
                  src/tm_mad/vcenter/snap_delete \
@@ -1167,7 +1168,8 @@ ONEDB_FILES="src/onedb/fsck.rb \
             src/onedb/vcenter_one54.rb \
             src/onedb/sqlite2mysql.rb \
             src/onedb/database_schema.rb \
-            src/onedb/fsck"
+            src/onedb/fsck \
+            src/onedb/onedb_live.rb"
 
 ONEDB_SHARED_MIGRATOR_FILES="src/onedb/shared/2.0_to_2.9.80.rb \
                              src/onedb/shared/2.9.80_to_2.9.85.rb \
