@@ -290,7 +290,7 @@ class OneImageHelper < OpenNebulaHelper::OneHelper
             puts str % [e,  mask]
         }
 
-        if image.has_elements?("/IMAGE/SNAPSHOTS")
+        if image.has_elements?("/IMAGE/SNAPSHOTS/SNAPSHOT")
             puts
             CLIHelper.print_header(str_h1 % "IMAGE SNAPSHOTS",false)
             format_snapshots(image)
@@ -361,7 +361,7 @@ class OneImageHelper < OpenNebulaHelper::OneHelper
 
         # Convert snapshot data to an array
         image_hash = image.to_hash
-        image_snapshots = [image_hash['IMAGE']['SNAPSHOTS']].flatten.first
+        image_snapshots = [image_hash['IMAGE']['SNAPSHOTS']['SNAPSHOT']].flatten
         table.show(image_snapshots)
     end
 
