@@ -169,7 +169,7 @@ class OneVMHelper < OpenNebulaHelper::OneHelper
         end
 
         vm_nics.each do |nic|
-            ["IP", "IP6_GLOBAL", "IP6_ULA",
+            ["IP", "IP6_GLOBAL", "IP6_ULA", "IP6",
              "VROUTER_IP", "VROUTER_IP6_GLOBAL", "VROUTER_IP6_ULA"].each do |attr|
                 if nic.has_key?(attr)
                     ips.push(nic[attr])
@@ -752,7 +752,7 @@ in the frontend machine.
 
                 next if nic.has_key?("CLI_DONE")
 
-                ["IP6_LINK", "IP6_ULA", "IP6_GLOBAL"].each do |attr|
+                ["IP6_LINK", "IP6_ULA", "IP6_GLOBAL", "IP6"].each do |attr|
                     if nic.has_key?(attr)
                         shown_ips << nic[attr]
 
@@ -1015,18 +1015,31 @@ in the frontend machine.
                 d["SEQ"]
             end
 
-            column :HOST, "Host name of the VM container", :left, :size=>15 do |d|
+            column :UID, "UID of the user that performed the action",
+                :left, :size=>4 do |d|
+                if d["UID"] != "-1"
+                    d["UID"]
+                else
+                    "-"
+                end
+            end
+
+            column :REQ, "Request ID of the action", :left, :size=>5 do |d|
+                if d["REQUEST_ID"] != "-1"
+                    d["REQUEST_ID"]
+                else
+                    "-"
+                end
+            end
+
+            column :HOST, "Host name of the VM container", :left, :size=>12 do |d|
                 d["HOSTNAME"]
             end
 
-            column :"ACTION", "VM state change action", :left, :size=>16 do |d|
+            column :"ACTION", "VM state change action", :left, :size=>10 do |d|
                 VirtualMachine.get_history_action d["ACTION"]
             end
 
-            column :REASON, "VM state change reason", :left, :size=>4 do |d|
-                VirtualMachine.get_reason d["REASON"]
-            end
-
             column :DS, "System Datastore", :size=>4 do |d|
                 d["DS_ID"]
             end
@@ -1053,7 +1066,7 @@ in the frontend machine.
                 OpenNebulaHelper.short_period_to_str(dtime)
             end
 
-            default :SEQ, :HOST, :ACTION, :DS, :START, :TIME, :PROLOG
+            default :SEQ, :UID, :REQ, :HOST, :ACTION, :DS, :START, :TIME, :PROLOG
         end
 
         vm_hash=vm.to_hash
