@@ -28,8 +28,10 @@ module OpenNebula
         EACTION         = 0x0800
         EXML_RPC_API    = 0x1000
         EINTERNAL       = 0x2000
-        ENOTDEFINED     = 0x1111
-
+        EALLOCATE       = 0x4000
+        ENOTDEFINED     = 0xF001
+        EXML_RPC_CALL   = 0xF002
+        
         attr_reader :message, :errno
 
         # +message+ Description of the error
@@ -42,6 +44,11 @@ module OpenNebula
         def to_str()
             @message
         end
+
+        def is_exml_rpc_call?()
+            @errno == EXML_RPC_CALL
+        end
+
     end
 
     # Returns true if the object returned by a method of the OpenNebula
@@ -49,4 +56,5 @@ module OpenNebula
     def self.is_error?(value)
         value.class==OpenNebula::Error
     end
+
 end
