@@ -59,7 +59,7 @@ int PoolObjectSQL::select(SqlDB *db)
     boid = oid;
     oid  = -1;
 
-    rc = db->exec(oss, this);
+    rc = db->exec_rd(oss, this);
 
     unset_callback();
 
@@ -101,7 +101,7 @@ int PoolObjectSQL::select(SqlDB *db, const string& _name, int _uid)
     name  = "";
     uid   = -1;
 
-    rc = db->exec(oss, this);
+    rc = db->exec_rd(oss, this);
 
     unset_callback();
 
@@ -125,7 +125,7 @@ int PoolObjectSQL::drop(SqlDB *db)
 
     oss << "DELETE FROM " << table << " WHERE oid=" << oid;
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     if ( rc == 0 )
     {
