@@ -118,6 +118,9 @@ define(function(require) {
     "DISK_SNAPSHOT_DELETE",
     "PROLOG_MIGRATE_UNKNOWN",
     "PROLOG_MIGRATE_UNKNOWN_FAILURE",
+    "DISK_RESIZE",
+    "DISK_RESIZE_POWEROFF",
+    "DISK_RESIZE_UNDEPLOYED"
   ];
 
   var LCM_STATES = {
@@ -182,7 +185,10 @@ define(function(require) {
     //DISK_SNAPSHOT_REVERT          : 58,
     DISK_SNAPSHOT_DELETE            : 59,
     PROLOG_MIGRATE_UNKNOWN          : 60,
-    PROLOG_MIGRATE_UNKNOWN_FAILURE  : 61
+    PROLOG_MIGRATE_UNKNOWN_FAILURE  : 61,
+    DISK_RESIZE                     : 62,
+    DISK_RESIZE_POWEROFF            : 63,
+    DISK_RESIZE_UNDEPLOYED          : 64
   };
 
   var SHORT_LCM_STATES_STR = [
@@ -248,6 +254,9 @@ define(function(require) {
     Locale.tr("SNAPSHOT"),  // DISK_SNAPSHOT_DELETE
     Locale.tr("MIGRATE"),   // PROLOG_MIGRATE_UNKNOWN
     Locale.tr("FAILURE"),   // PROLOG_MIGRATE_UNKNOWN_FAILURE
+    Locale.tr("DISK_RSZ"),  // DISK_RESIZE
+    Locale.tr("DISK_RSZ"),  // DISK_RESIZE_POWEROFF
+    Locale.tr("DISK_RSZ")   // DISK_RESIZE_UNDEPLOYED
   ];
 
   var VNC_STATES = [
@@ -263,13 +272,17 @@ define(function(require) {
     LCM_STATES.HOTPLUG_SAVEAS,
     LCM_STATES.HOTPLUG_SAVEAS_POWEROFF,
     LCM_STATES.HOTPLUG_SAVEAS_SUSPENDED,
-    LCM_STATES.SHUTDOWN_UNDEPLOY
+    LCM_STATES.SHUTDOWN_UNDEPLOY,
+    LCM_STATES.DISK_SNAPSHOT,
+    LCM_STATES.DISK_SNAPSHOT_REVERT,
+    LCM_STATES.DISK_RESIZE
   ];
 
   var EXTERNAL_IP_ATTRS = [
     'GUEST_IP',
     'GUEST_IP_ADDRESSES',
     'AWS_IP_ADDRESS',
+    'AWS_PUBLIC_IP_ADDRESS',
     'AWS_PRIVATE_IP_ADDRESS',
     'AZ_IPADDRESS',
     'SL_PRIMARYIPADDRESS'
@@ -277,6 +290,7 @@ define(function(require) {
 
   var NIC_IP_ATTRS = [
     "IP",
+    "IP6",
     "IP6_GLOBAL",
     "IP6_ULA",
     "VROUTER_IP",
@@ -289,6 +303,8 @@ define(function(require) {
     'GUEST_IP_ADDRESSES',
     'AWS_IP_ADDRESS',
     'AWS_DNS_NAME',
+    'AWS_PUBLIC_IP_ADDRESS',
+    'AWS_PUBLIC_DNS_NAME',
     'AWS_PRIVATE_IP_ADDRESS',
     'AWS_PRIVATE_DNS_NAME',
     'AWS_SECURITY_GROUPS',
@@ -296,12 +312,6 @@ define(function(require) {
     'SL_PRIMARYIPADDRESS'
   ];
 
-  var MIGRATE_REASON = [
-    "NONE",
-    "ERROR",
-    "USER"
-  ];
-
   var MIGRATE_ACTION_STR = [
     "none",                // NONE_ACTION            = 0
     "migrate",             // MIGRATE_ACTION         = 1
@@ -331,7 +341,23 @@ define(function(require) {
     "snap-create",         // DISK_SNAPSHOT_CREATE_ACTION = 25
     "snap-delete",         // DISK_SNAPSHOT_DELETE_ACTION = 26
     "terminate",           // TERMINATE_ACTION       = 27
-    "terminate-hard"       // TERMINATE_HARD_ACTION  = 28
+    "terminate-hard",      // TERMINATE_HARD_ACTION  = 28
+    "disk-resize",         // DISK_RESIZE_ACTION     = 29
+    "deploy",              // DEPLOY_ACTION          = 30
+    "chown",               // CHOWN_ACTION           = 31
+    "chmod",               // CHMOD_ACTION           = 32
+    "updateconf",          // UPDATECONF_ACTION      = 33
+    "rename",              // RENAME_ACTION          = 34
+    "resize",              // RESIZE_ACTION          = 35
+    "update",              // UPDATE_ACTION          = 36
+    "snapshot-create",     // SNAPSHOT_CREATE_ACTION = 37
+    "snapshot-delete",     // SNAPSHOT_DELETE_ACTION = 38
+    "snapshot-revert",     // SNAPSHOT_REVERT_ACTION = 39
+    "disk-saveas",         // DISK_SAVEAS_ACTION     = 40
+    "disk-snapshot-revert",// DISK_SNAPSHOT_REVERT_ACTION = 41
+    "recover",             // RECOVER_ACTION         = 42
+    "retry",               // RETRY_ACTION           = 43
+    "monitor",             // MONITOR_ACTION         = 44
   ];
 
   var VM = {
@@ -493,6 +519,10 @@ define(function(require) {
       var action_obj = params.data.extra_param;
       OpenNebulaAction.simple_action(params, RESOURCE, "resize", action_obj);
     },
+    "disk_resize" : function(params) {
+      var action_obj = params.data.extra_param;
+      OpenNebulaAction.simple_action(params, RESOURCE, "disk_resize", action_obj);
+    },
     "attachdisk" : function(params) {
       var action_obj = {"disk_template": params.data.extra_param};
       OpenNebulaAction.simple_action(params, RESOURCE, "attachdisk", action_obj);
@@ -605,13 +635,11 @@ define(function(require) {
     "migrateActionStr": function(stateId) {
       return MIGRATE_ACTION_STR[stateId];
     },
-    "migrateReasonStr": function(stateId) {
-      return MIGRATE_REASON[stateId];
-    },
     "ipsStr": ipsStr,
     "retrieveExternalIPs": retrieveExternalIPs,
     "retrieveExternalNetworkAttrs": retrieveExternalNetworkAttrs,
     "isNICGraphsSupported": isNICGraphsSupported,
+    "isDiskGraphsSupported": isDiskGraphsSupported,
     "isNICAttachSupported": isNICAttachSupported,
     "isVNCSupported": isVNCSupported,
     "isSPICESupported": isSPICESupported,
@@ -643,6 +671,15 @@ define(function(require) {
     }
   }
 
+   function isDiskGraphsSupported(element) {
+    var history = retrieveLastHistoryRecord(element)
+    if (history) {
+      return $.inArray(history.VM_MAD, ['ec2','az']) == -1;
+    } else {
+      return false;
+    }
+  }
+
   function isNICAttachSupported(element) {
     var history = retrieveLastHistoryRecord(element)
     if (history) {
