@@ -40,6 +40,9 @@ History::History(
         ObjectXML(),
         oid(_oid),
         seq(_seq),
+        uid(-1),
+        gid(-1),
+        req_id(-1),
         hid(-1),
         hostname(""),
         cid(-1),
@@ -71,6 +74,9 @@ History::History(
     const string& _vm_info):
         oid(_oid),
         seq(_seq),
+        uid(-1),
+        gid(-1),
+        req_id(-1),
         hid(_hid),
         hostname(_hostname),
         cid(_cid),
@@ -238,6 +244,11 @@ int History::select(SqlDB * db)
 
     unset_callback();
 
+	if ( hostname.empty() )
+	{
+		rc = -1;
+	}
+
     if ( rc == 0 ) // Regenerate non-persistent data
     {
         non_persistent_data();
