@@ -2138,7 +2138,7 @@ int VirtualMachine::from_xml(const string &xml_str)
 
     for (vector<xmlNodePtr>::iterator it=content.begin();it!=content.end();it++)
     {
-        Snapshots * snap = new Snapshots(-1);
+        Snapshots * snap = new Snapshots(-1, false);
 
         rc += snap->from_xml_node(*it);
 
