@@ -33,7 +33,13 @@ module SGIPTables
         def process_protocol(cmds, vars)
             chain = @rule_type == :inbound ? vars[:chain_in] : vars[:chain_out]
 
-            cmds.add :iptables, "-A #{chain} -p #{@protocol} -j RETURN"
+            if @protocol != :icmpv6
+                cmds.add :iptables, "-A #{chain} -p #{@protocol} -j RETURN"
+            end
+
+            if @protocol != :icmp
+                cmds.add :ip6tables, "-A #{chain} -p #{@protocol} -j RETURN"
+            end
         end
 
         # Implements the :portrange rule. Example:
@@ -43,72 +49,123 @@ module SGIPTables
 
             cmds.add :iptables, "-A #{chain} -p #{@protocol} -m multiport" \
                 " --dports #{@range} -j RETURN"
+            cmds.add :ip6tables, "-A #{chain} -p #{@protocol} -m multiport" \
+                " --dports #{@range} -j RETURN"
         end
 
         # Implements the :icmp_type rule. Example:
         #   iptables -A one-3-0-o -p icmp --icmp-type 8 -j RETURN
-        def     process_icmp_type(cmds, vars)
+        def process_icmp_type(cmds, vars)
             chain = @rule_type == :inbound ? vars[:chain_in] : vars[:chain_out]
 
-            cmds.add :iptables, "-A #{chain} -p icmp --icmp-type #{@icmp_type}" \
+            cmds.add :iptables, "-A #{chain} -p icmp --icmp-type #{@icmp_type}"\
                 " -j RETURN"
         end
 
+        # Implements the :icmpv6_type rule. Example:
+        #   ip6tables -A one-3-0-o -p icmpv6 --icmpv6-type 128 -j RETURN
+        def process_icmpv6_type(cmds, vars)
+            chain = @rule_type == :inbound ? vars[:chain_in] : vars[:chain_out]
+
+            cmds.add :ip6tables, "-A #{chain} -p icmpv6 --icmpv6-type "\
+                "#{@icmpv6_type} -j RETURN"
+        end
+
         # Implements the :net rule. Example:
-        #   ipset create one-3-0-1-i-tcp-n hash:net
-        #   iptables -A one-3-0-i -p tcp -m set --match-set one-3-0-1-i src -j RETURN
-        #   ipset add -exist one-3-0-1-i-tcp-n 10.0.0.0/24
+        #   ipset create one-3-0-1-i-tcp-n-inet hash:net family inet
+        #   iptables -A one-3-0-i -p tcp -m set --match-set \
+        #       one-3-0-1-i-tcp-n-inet src -j RETURN
+        #   ipset add -exist one-3-0-1-i-tcp-n-inet 10.0.0.0/24
         def process_net(cmds, vars)
-            if @rule_type == :inbound
-                chain = vars[:chain_in]
-                set = "#{vars[:set_sg_in]}-#{@protocol}-n"
-                dir = "src"
-            else
-                chain = vars[:chain_out]
-                set = "#{vars[:set_sg_out]}-#{@protocol}-n"
-                dir = "dst"
-            end
+            the_nets = net()
 
-            cmds.add :ipset, "create #{set} hash:net"
-            cmds.add :iptables, "-A #{chain} -p #{@protocol} -m set" \
-                " --match-set #{set} #{dir} -j RETURN"
+            return if the_nets.empty?
+
+            sets = []
+
+            the_nets.each do |n|
+                if IPAddr.new(n).ipv6?
+                    command = :ip6tables
+                    family  = "inet6"
+                else
+                    command = :iptables
+                    family  = "inet"
+                end
+
+                if @rule_type == :inbound
+                    chain = vars[:chain_in]
+                    set = "#{vars[:set_sg_in]}-#{@protocol}-n-#{family}"
+                    dir = "src"
+                else
+                    chain = vars[:chain_out]
+                    set = "#{vars[:set_sg_out]}-#{@protocol}-n-#{family}"
+                    dir = "dst"
+                end
+
+                if !sets.include?(set)
+                    cmds.add :ipset, "create #{set} hash:net family #{family}"
+                    cmds.add command, "-A #{chain} -p #{@protocol} -m set" \
+                        " --match-set #{set} #{dir} -j RETURN"
+
+                    sets << set
+                end
 
-            net.each do |n|
                 cmds.add :ipset, "add -exist #{set} #{n}"
             end
         end
 
         # Implements the :net_portrange rule. Example:
-        #   ipset create one-3-0-1-i-nr hash:net,port
-        #   iptables -A one-3-0-i -m set --match-set one-3-0-1-i-nr src,dst -j RETURN
-        #   ipset add -exist one-3-0-1-i-nr 10.0.0.0/24,tcp:80
+        #   ipset create one-3-0-1-i-nr-inet hash:net,port family inet
+        #   iptables -A one-3-0-i -m set --match-set one-3-0-1-i-nr-inet src,dst
+        #        -j RETURN
+        #   ipset add -exist one-3-0-1-i-nr-inet 10.0.0.0/24,tcp:80
         def process_net_portrange(cmds, vars)
-            if @rule_type == :inbound
-                chain = vars[:chain_in]
-                set = "#{vars[:set_sg_in]}-nr"
-                dir = "src,dst"
-            else
-                chain = vars[:chain_out]
-                set = "#{vars[:set_sg_out]}-nr"
-                dir = "dst,dst"
-            end
+            the_nets = net()
 
-            cmds.add :ipset, "create #{set} hash:net,port"
-            cmds.add :iptables, "-A #{chain} -m set --match-set" \
-                " #{set} #{dir} -j RETURN"
+            return if the_nets.empty?
+
+            sets = []
+
+            the_nets.each do |n|
+                if IPAddr.new(n).ipv6?
+                    command = :ip6tables
+                    family  = "inet6"
+                else
+                    command = :iptables
+                    family  = "inet"
+                end
+
+                if @rule_type == :inbound
+                    chain = vars[:chain_in]
+                    set = "#{vars[:set_sg_in]}-nr-#{family}"
+                    dir = "src,dst"
+                else
+                    chain = vars[:chain_out]
+                    set = "#{vars[:set_sg_out]}-nr-#{family}"
+                    dir = "dst,dst"
+                end
+
+                if !sets.include?(set)
+                    cmds.add :ipset, "create #{set} hash:net,port family #{family}"
+                    cmds.add command, "-A #{chain} -m set --match-set" \
+                        " #{set} #{dir} -j RETURN"
+
+                    sets << set
+                end
 
-            net.each do |n|
                 @range.split(",").each do |r|
                     r.gsub!(":","-")
                     net_range = "#{n},#{@protocol}:#{r}"
+
                     cmds.add :ipset, "add -exist #{set} #{net_range}"
                 end
             end
         end
 
         # Implements the :net_icmp_type rule. Example:
-        #   ipset create one-3-0-1-i-ni hash:net,port
-        #   iptables -A one-3-0-i -m set --match-set one-3-0-1-i-nr src,dst -j RETURN
+        #   ipset create one-3-0-1-i-ni hash:net,port family inet
+        #   iptables -A one-3-0-i -m set --match-set one-3-0-1-i-ni src,dst
+        #       -j RETURN
         #   ipset add -exist one-3-0-1-i-ni 10.0.0.0/24,icmp:8/0
         def process_net_icmp_type(cmds, vars)
             if @rule_type == :inbound
@@ -121,8 +178,9 @@ module SGIPTables
                 dir = "dst,dst"
             end
 
-            cmds.add :ipset, "create #{set} hash:net,port"
-            cmds.add :iptables, "-A #{chain} -m set --match-set #{set} #{dir} -j RETURN"
+            cmds.add :ipset, "create #{set} hash:net,port family inet"
+            cmds.add :iptables, "-A #{chain} -m set --match-set #{set} #{dir}"\
+                " -j RETURN"
 
             net.each do |n|
                 icmp_type_expand.each do |type_code|
@@ -130,6 +188,33 @@ module SGIPTables
                 end
             end
         end
+
+        # Implements the :net_icmpv6_type rule. Example:
+        #   ipset create one-3-0-1-i-ni6 hash:net,port family inet6
+        #   ip6tables -A one-3-0-i -m set --match-set one-3-0-1-i-ni6 src,dst
+        #       -j RETURN
+        #   ipset add -exist one-3-0-1-i-ni6 10.0.0.0/24,icmpv6:128/0
+        def process_net_icmpv6_type(cmds, vars)
+            if @rule_type == :inbound
+                chain = vars[:chain_in]
+                set = "#{vars[:set_sg_in]}-ni6"
+                dir = "src,dst"
+            else
+                chain = vars[:chain_out]
+                set = "#{vars[:set_sg_out]}-ni6"
+                dir = "dst,dst"
+            end
+
+            cmds.add :ipset, "create #{set} hash:net,port family inet6"
+            cmds.add :ip6tables, "-A #{chain} -m set --match-set #{set} #{dir}"\
+                " -j RETURN"
+
+            net.each do |n|
+                icmpv6_type_expand.each do |type_code|
+                    cmds.add :ipset, "add -exist #{set} #{n},icmpv6:#{type_code}"
+                end
+            end
+        end
     end
 
     ############################################################################
@@ -166,19 +251,30 @@ module SGIPTables
         commands.add :iptables, "-S"
         iptables_s = commands.run!
 
+        commands.add :ip6tables, "-S"
+        ip6tables_s = commands.run!
+
         iptables_forwards = ""
+        ip6tables_forwards = ""
 
         if iptables_s.match(/^-N #{GLOBAL_CHAIN}$/)
             commands.add :iptables, "-L #{GLOBAL_CHAIN} --line-numbers"
             iptables_forwards = commands.run!
         end
 
+        if ip6tables_s.match(/^-N #{GLOBAL_CHAIN}$/)
+            commands.add :ip6tables, "-L #{GLOBAL_CHAIN} --line-numbers"
+            ip6tables_forwards = commands.run!
+        end
+
         commands.add :ipset, "list -name"
         ipset_list = commands.run!
 
         {
             :iptables_forwards => iptables_forwards,
             :iptables_s => iptables_s,
+            :ip6tables_forwards => ip6tables_forwards,
+            :ip6tables_s => ip6tables_s,
             :ipset_list => ipset_list
         }
     end
@@ -190,15 +286,23 @@ module SGIPTables
     def self.global_bootstrap
         info = SGIPTables.info
 
-        return if info[:iptables_s].split("\n").include? "-N #{GLOBAL_CHAIN}"
-
         commands = VNMNetwork::Commands.new
 
-        commands.add :iptables, "-N #{GLOBAL_CHAIN}"
-        commands.add :iptables, "-A FORWARD -m physdev --physdev-is-bridged -j #{GLOBAL_CHAIN}"
-        commands.add :iptables, "-A #{GLOBAL_CHAIN} -j ACCEPT"
+        if !info[:iptables_s].split("\n").include?("-N #{GLOBAL_CHAIN}")
+            commands.add :iptables, "-N #{GLOBAL_CHAIN}"
+            commands.add :iptables, "-A FORWARD -m physdev "\
+                "--physdev-is-bridged -j #{GLOBAL_CHAIN}"
+            commands.add :iptables, "-A #{GLOBAL_CHAIN} -j ACCEPT"
+        end
 
-        commands.run!
+        if !info[:ip6tables_s].split("\n").include?("-N #{GLOBAL_CHAIN}")
+            commands.add :ip6tables, "-N #{GLOBAL_CHAIN}"
+            commands.add :ip6tables, "-A FORWARD -m physdev "\
+                "--physdev-is-bridged -j #{GLOBAL_CHAIN}"
+            commands.add :ip6tables, "-A #{GLOBAL_CHAIN} -j ACCEPT"
+        end
+
+        commands.run! if !commands.empty?
     end
 
     # Returns the base chain and ipset names for the VM
@@ -237,8 +341,10 @@ module SGIPTables
     #  Example, for VM 3 and NIC 0
     #   iptables -N one-3-0-i
     #   iptables -N one-3-0-o
-    #   iptables -I opennebula -m physdev --physdev-out vnet0 --physdev-is-bridged -j one-3-0-i"
-    #   iptables -I opennebula -m physdev --physdev-in  vnet0 --physdev-is-bridged -j one-3-0-o"
+    #   iptables -I opennebula -m physdev --physdev-out vnet0
+    #       --physdev-is-bridged -j one-3-0-i"
+    #   iptables -I opennebula -m physdev --physdev-in  vnet0
+    #       --physdev-is-bridged -j one-3-0-o"
     #   iptables -A one-3-0-i -m state --state ESTABLISHED,RELATED -j ACCEPT
     #   iptables -A one-3-0-o -m state --state ESTABLISHED,RELATED -j ACCEPT
     #
@@ -259,32 +365,117 @@ module SGIPTables
         # create chains
         commands.add :iptables, "-N #{chain_in}"  # inbound
         commands.add :iptables, "-N #{chain_out}" # outbound
+        commands.add :ip6tables, "-N #{chain_in}"  # inbound
+        commands.add :ip6tables, "-N #{chain_out}" # outbound
 
         # Send traffic to the NIC chains
-        commands.add :iptables, "-I #{GLOBAL_CHAIN} -m physdev --physdev-out #{nic[:tap]} --physdev-is-bridged -j #{chain_in}"
-        commands.add :iptables, "-I #{GLOBAL_CHAIN} -m physdev --physdev-in  #{nic[:tap]} --physdev-is-bridged -j #{chain_out}"
+        commands.add :iptables, "-I #{GLOBAL_CHAIN} -m physdev "\
+            "--physdev-out #{nic[:tap]} --physdev-is-bridged -j #{chain_in}"
+        commands.add :iptables, "-I #{GLOBAL_CHAIN} -m physdev "\
+            "--physdev-in  #{nic[:tap]} --physdev-is-bridged -j #{chain_out}"
+
+        commands.add :ip6tables, "-I #{GLOBAL_CHAIN} -m physdev "\
+            "--physdev-out #{nic[:tap]} --physdev-is-bridged -j #{chain_in}"
+        commands.add :ip6tables, "-I #{GLOBAL_CHAIN} -m physdev "\
+            "--physdev-in  #{nic[:tap]} --physdev-is-bridged -j #{chain_out}"
+
+        # ICMPv6 Neighbor Discovery Protocol (ARP replacement for IPv6)
+        ## Allow routers to send router advertisements
+        commands.add :ip6tables, "-A #{chain_in} -p icmpv6 --icmpv6-type 134 "\
+            "-j ACCEPT"
+
+        ## Allow neighbor solicitations to reach the host
+        commands.add :ip6tables, "-A #{chain_in} -p icmpv6 --icmpv6-type 135 "\
+            "-j ACCEPT"
+
+        ## Allow neighbor solicitations replies to reach the host
+        commands.add :ip6tables, "-A #{chain_in} -p icmpv6 --icmpv6-type 136 "\
+            "-j ACCEPT"
+
+        ## Allow routers to send Redirect messages
+        commands.add :ip6tables, "-A #{chain_in} -p icmpv6 --icmpv6-type 137 "\
+            "-j ACCEPT"
+
+        ## Allow the host to send a router solicitation
+        commands.add :ip6tables, "-A #{chain_out} -p icmpv6 --icmpv6-type 133 "\
+            "-j ACCEPT"
+
+        ## Allow the host to send neighbor solicitation requests
+        commands.add :ip6tables, "-A #{chain_out} -p icmpv6 --icmpv6-type 135 "\
+            "-j ACCEPT"
+
+        ## Allow the host to send neighbor solicitation replies
+        commands.add :ip6tables, "-A #{chain_out} -p icmpv6 --icmpv6-type 136 "\
+            "-j ACCEPT"
 
         # Mac-spofing
         if nic[:filter_mac_spoofing] == "YES"
-            commands.add :iptables, "-A #{chain_out} -m mac ! --mac-source #{nic[:mac]} -j DROP"
+            commands.add :iptables, "-A #{chain_out} -m mac ! "\
+                "--mac-source #{nic[:mac]} -j DROP"
+            commands.add :ip6tables, "-A #{chain_out} -m mac ! "\
+                "--mac-source #{nic[:mac]} -j DROP"
         end
 
         # IP-spofing
         if nic[:filter_ip_spoofing] == "YES"
-            commands.add :iptables, "-A #{chain_out} -p udp --source 0.0.0.0/32 --sport 68 --destination 255.255.255.255/32 --dport 67 -j ACCEPT"
+            ipv4s = Array.new
 
-            set = "#{vars[:chain]}-ip-spoofing"
+            [:ip, :vrouter_ip].each do |key|
+                ipv4s << nic[key] if !nic[key].nil? && !nic[key].empty?
+            end
 
-            commands.add :ipset, "create #{set} hash:ip"
-            commands.add :ipset, "add -exist #{set} #{nic[:ip]}"
-            commands.add :ipset, "add -exist #{set} #{nic[:vrouter_ip]}" if nic[:vrouter_ip]
+            if !ipv4s.empty?
+                #bootp
+                commands.add :iptables, "-A #{chain_out} -p udp "\
+                    "--source 0.0.0.0/32 --sport 68 --destination "\
+                    "255.255.255.255/32 --dport 67 -j ACCEPT"
 
-            commands.add :iptables, "-A #{chain_out} -m set ! --match-set #{set} src -j DROP"
+                set = "#{vars[:chain]}-ip-spoofing"
+
+                commands.add :ipset, "create #{set} hash:ip family inet"
+
+                ipv4s.each do |ip|
+                    commands.add :ipset, "add -exist #{set} #{ip}"
+                end
+
+                commands.add :iptables, "-A #{chain_out} -m set ! "\
+                    "--match-set #{set} src -j DROP"
+            else # If there are no IPv4 addresses allowed, block all
+                commands.add :iptables, "-A #{chain_out} --source 0.0.0.0/0 "\
+                    "-j DROP"
+            end
+
+            ipv6s = Array.new
+
+            [:ip6_global, :ip6_link, :ip6_ula].each do |key|
+                ipv6s << nic[key] if !nic[key].nil? && !nic[key].empty?
+            end
+
+            if !ipv6s.empty?
+                set = "#{vars[:chain]}-ip6-spoofing"
+
+                commands.add :ipset, "create #{set} hash:ip family inet6"
+
+                ipv6s.each do |ip|
+                    commands.add :ipset, "add -exist #{set} #{ip}"
+                end
+
+                commands.add :ip6tables, "-A #{chain_out} -m set ! "\
+                    "--match-set #{set} src -j DROP"
+            else # If there are no IPv6 addresses allowed, block all
+                commands.add :ip6tables, "-A #{chain_out} --source ::/0 -j DROP"
+            end
         end
 
         # Related, Established
-        commands.add :iptables, "-A #{chain_in} -m state --state ESTABLISHED,RELATED -j ACCEPT"
-        commands.add :iptables, "-A #{chain_out} -m state --state ESTABLISHED,RELATED -j ACCEPT"
+        commands.add :iptables, "-A #{chain_in} -m state"\
+            " --state ESTABLISHED,RELATED -j ACCEPT"
+        commands.add :iptables, "-A #{chain_out} -m state"\
+            " --state ESTABLISHED,RELATED -j ACCEPT"
+        commands.add :ip6tables, "-A #{chain_in} -m state"\
+            " --state ESTABLISHED,RELATED -j ACCEPT"
+        commands.add :ip6tables, "-A #{chain_out} -m state"\
+            " --state ESTABLISHED,RELATED -j ACCEPT"
 
         commands.run!
     end
@@ -300,6 +491,8 @@ module SGIPTables
         commands = VNMNetwork::Commands.new
         commands.add :iptables, "-A #{chain_in} -j DROP"
         commands.add :iptables, "-A #{chain_out} -j DROP"
+        commands.add :ip6tables, "-A #{chain_in} -j DROP"
+        commands.add :ip6tables, "-A #{chain_out} -j DROP"
 
         commands.run!
     end
@@ -314,6 +507,8 @@ module SGIPTables
         info              = self.info
         iptables_forwards = info[:iptables_forwards]
         iptables_s        = info[:iptables_s]
+        ip6tables_forwards= info[:ip6tables_forwards]
+        ip6tables_s       = info[:ip6tables_s]
         ipset_list        = info[:ipset_list]
 
         commands = VNMNetwork::Commands.new
@@ -326,6 +521,14 @@ module SGIPTables
             end
         end
 
+        ip6tables_forwards.lines.reverse_each do |line|
+            fields = line.split
+            if [chain_in, chain_out].include?(fields[1])
+                n = fields[0]
+                commands.add :ip6tables, "-D #{GLOBAL_CHAIN} #{n}"
+            end
+        end
+
         remove_chains = []
         iptables_s.lines.each do |line|
             if line.match(/^-N #{chain}(-|$)/)
@@ -334,6 +537,8 @@ module SGIPTables
         end
         remove_chains.each {|c| commands.add :iptables, "-F #{c}" }
         remove_chains.each {|c| commands.add :iptables, "-X #{c}" }
+        remove_chains.each {|c| commands.add :ip6tables, "-F #{c}" }
+        remove_chains.each {|c| commands.add :ip6tables, "-X #{c}" }
 
         ipset_list.lines.each do |line|
             if line.match(/^#{chain}(-|$)/)
