@@ -18,6 +18,7 @@
 #include "VirtualNetworkPool.h"
 #include "Nebula.h"
 #include "VirtualMachine.h"
+#include "Request.h"
 
 static const History::VMAction action[15] = {
     History::MIGRATE_ACTION,
@@ -149,8 +150,6 @@ int VirtualRouter::drop(SqlDB * db)
     {
         release_network_leases();
 
-        shutdown_vms();
-
         Quotas::quota_del(Quotas::VIRTUALROUTER, uid, gid, obj_template);
     }
 
@@ -160,22 +159,22 @@ int VirtualRouter::drop(SqlDB * db)
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 
-int VirtualRouter::shutdown_vms()
+int VirtualRouter::shutdown_vms(const set<int>& _vms, const RequestAttributes& ra)
 {
     DispatchManager * dm = Nebula::instance().get_dm();
 
-    set<int> _vms;
-    set<int>::iterator  it;
+    set<int>::const_iterator  it;
 
     string error;
+
     int rc;
     int result = 0;
 
-    _vms = vms.get_collection();
-
     for (it = _vms.begin(); it != _vms.end(); it++)
     {
-        rc = dm->terminate(*it, true, error);
+        int vm_id = *it;
+
+        rc = dm->terminate(vm_id, true, ra, error);
 
         if (rc != 0)
         {
@@ -183,7 +182,7 @@ int VirtualRouter::shutdown_vms()
 
             if (rc == -2)
             {
-                dm->delete_vm(*it, error);
+                dm->delete_vm(vm_id, ra, error);
             }
         }
     }
@@ -206,7 +205,9 @@ int VirtualRouter::get_network_leases(string& estr)
 
     for(int i=0; i<num_nics; i++)
     {
-        if (vnpool->nic_attribute(PoolObjectSQL::VROUTER, nics[i], i, uid, oid,
+        VirtualMachineNic nic(nics[i], i);
+
+        if (vnpool->nic_attribute(PoolObjectSQL::VROUTER, &nic, i, uid, oid,
                 estr) == -1)
         {
             return -1;
@@ -271,7 +272,7 @@ int VirtualRouter::insert_replace(SqlDB *db, bool replace, string& error_str)
         <<            group_u    << ","
         <<            other_u    << ")";
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     db->free_str(sql_name);
     db->free_str(sql_xml);
@@ -452,7 +453,7 @@ void vrouter_prefix(VectorAttribute* nic, const string& attr)
 
 /* -------------------------------------------------------------------------- */
 
-void prepare_nic_vm(VectorAttribute* nic)
+static void prepare_nic_vm(VectorAttribute * nic)
 {
     bool floating = false;
     nic->vector_value("FLOATING_IP", floating);
@@ -590,7 +591,6 @@ VectorAttribute * VirtualRouter::attach_nic(
     vector<VectorAttribute *>   nics;
 
     vector<VectorAttribute *>::const_iterator it;
-    VectorAttribute *           nic;
 
     int rc;
     int nic_id;
@@ -629,23 +629,23 @@ VectorAttribute * VirtualRouter::attach_nic(
         return 0;
     }
 
-    nic = nics[0];
+    VirtualMachineNic nic(nics[0], nic_id);
 
-    rc = vnpool->nic_attribute(PoolObjectSQL::VROUTER,
-                        nic, nic_id, uid, oid, error_str);
+    rc = vnpool->nic_attribute(PoolObjectSQL::VROUTER, &nic, nic_id, uid, oid,
+            error_str);
 
     if (rc == -1)
     {
         return 0;
     }
 
-    obj_template->set(nic->clone());
+    VectorAttribute * new_nic = nic.vector_attribute()->clone();
 
-    nic = nic->clone();
+    prepare_nic_vm(new_nic);
 
-    prepare_nic_vm(nic);
+    obj_template->set(new_nic);
 
-    return nic;
+    return new_nic;
 }
 
 /* -------------------------------------------------------------------------- */
@@ -702,22 +702,14 @@ VectorAttribute* VirtualRouter::get_nic(int nic_id) const
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void VirtualRouter::set_auth_request(int uid,
-                                     AuthRequest& ar,
-                                     Template *tmpl)
+void VirtualRouter::set_auth_request(int uid, AuthRequest& ar, Template *tmpl)
 {
-    vector<VectorAttribute* > nics;
-    vector<VectorAttribute* >::const_iterator nics_it;
+    VirtualMachineNics::nic_iterator nic;
+    VirtualMachineNics tnics(tmpl);
 
-    Nebula& nd = Nebula::instance();
-
-    VirtualNetworkPool * vnpool = nd.get_vnpool();
-
-    tmpl->get("NIC", nics);
-
-    for (nics_it = nics.begin(); nics_it != nics.end(); nics_it++)
+    for( nic = tnics.begin(); nic != tnics.end(); ++nic)
     {
-        vnpool->authorize_nic(PoolObjectSQL::VROUTER, *nics_it, uid, &ar);
+        (*nic)->authorize_vrouter(uid, &ar);
     }
 }
 
